pylspci
=======

A Python parser for the ``lspci`` command from the pciutils_ package.
`Browse documentation`_

.. _pciutils: http://mj.ucw.cz/sw/pciutils/
.. _Browse documentation: https://lucidiot.gitlab.io/pylspci/
